@@ -28,9 +28,10 @@ required for classical geometry.
 
 import cppyy
 
-from sage.all import QQ, UniqueRepresentation, ZZ, RR, Fields, RealBallField, AA, Morphism, Hom, SetsWithPartialMaps, NumberField, NumberFields, RealBallField, CommutativeRing
+from sage.all import QQ, UniqueRepresentation, ZZ, RR, Fields, AA, Morphism, Hom, SetsWithPartialMaps, NumberField, NumberFields, RealBallField, CommutativeRing
 from sage.structure.element import FieldElement
 from sage.categories.map import Map
+from sage.misc.cachefunc import weak_cached_function
 
 from pyeantic import eantic
 
@@ -108,17 +109,26 @@ class RealEmbeddedNumberFieldElement(FieldElement):
             sage: isinstance(a, RealEmbeddedNumberFieldElement)
             True
 
+        A type of conversion that used to be very slow::
+
+            sage: K = NumberField(x^200 - 2, 'a', embedding=AA(2)^(1/200))
+            sage: L = RealEmbeddedNumberField(K)
+            sage: b = K.gen()^199
+            sage: L(b) * L(K.gen()) == 2
+            True
+
         """
         if isinstance(value, cppyy.gbl.eantic.renf_elem_class):
             self.renf_elem = value
         else:
             value = parent.number_field(value)
-            self.renf_elem = parent.renf.zero()
+            coefficients = value.polynomial().list()
 
-            gen_pow = parent.renf.one()
-            for coeff in value.polynomial().coefficients(sparse=False):
-                self.renf_elem = self.renf_elem + coeff * gen_pow
-                gen_pow = gen_pow * parent.renf.gen()
+            from gmpxxyy import mpq
+            # See https://github.com/flatsurf/gmpxxyy/issues/11 for a possible speedup.
+            coefficients = [mpq(str(c)) for c in coefficients]
+            coefficients = cppyy.gbl.std.vector[cppyy.gbl.mpq_class](coefficients)
+            self.renf_elem = cppyy.gbl.eantic.renf_elem_class(parent.renf, coefficients)
 
         FieldElement.__init__(self, parent)
 
@@ -382,7 +392,9 @@ class RealEmbeddedNumberField(UniqueRepresentation, CommutativeRing):
     @staticmethod
     def __classcall__(cls, embed, category=None):
         r"""
-        Normalize parameters so embedded real number fields are unique::
+        Normalize parameters so embedded real number fields are unique:
+
+        EXAMPLES::
 
             sage: from pyeantic import eantic, RealEmbeddedNumberField
             sage: K = NumberField(x**2 - 2, 'a', embedding=sqrt(AA(2)))
@@ -411,6 +423,31 @@ class RealEmbeddedNumberField(UniqueRepresentation, CommutativeRing):
             sage: RealEmbeddedNumberField(K)
             Real Embedded Number Field in x with defining polynomial x - 1 with x = 1
 
+        """
+        embed = cls._normalize_embedding(embed)
+        category = category or Fields()
+        return super(RealEmbeddedNumberField, cls).__classcall__(cls, embed, category)
+
+    @staticmethod
+    @weak_cached_function
+    def _normalize_embedding(embed):
+        r"""
+        Return the normalized SageMath number field with an embedding that is
+        compatible with the embedding ``embed``.
+
+        This is a helper method for ``__classcall__`` to make sure that real
+        embedded number fields are unique parents.
+
+        TESTS:
+
+        If ``embed`` is already a number field with an embedding into the
+        reals, then it is left alone::
+
+            sage: from pyeantic.real_embedded_number_field import RealEmbeddedNumberField
+            sage: K = NumberField(x**2 - 3, 'a', embedding=sqrt(AA(3)))
+            sage: RealEmbeddedNumberField._normalize_embedding(K) is K
+            True
+
         """
         if 'cppyy.gbl.boost.intrusive_ptr<const eantic::renf_class>' in str(type(embed)):
             embed = embed.get()
@@ -471,8 +508,7 @@ class RealEmbeddedNumberField(UniqueRepresentation, CommutativeRing):
         else:
             raise TypeError("cannot build RealEmbeddedNumberField from embedding %s" % (type(embed)))
 
-        category = category or Fields()
-        return super(RealEmbeddedNumberField, cls).__classcall__(cls, embed, category)
+        return embed
 
     def __init__(self, embedded, category=None):
         r"""
